# -*- coding: cp1251 -*-

"""
Tool Name:     Create Digital Model Template
Source Name:   CreateDigitalModelTemplate.py
Version:       ArcGIS 10.x
Author:        Anatoly Baranov
Organization:  VSEGEI
Description:   Creates a folder with shp and dbf files for the GGK digital model structure
"""

#--------------------------------------IMPORTS-------------------------------------------

from os import *
from arcpy import *

#--------------------------------------FUNCTIONS-------------------------------------------


def isInt(value):
    '''Checks if the string value
        could be modified to an integer
        
    INPUT:
        value (str)
    OUTPUT:
        bool
    '''
    
    try:
        int(value)
        return True
    except:
        return False



def defineGeometry(name):
    '''Checks the last char of the filename and
        returns the name of the geometry type,
        corresponding to the input char
        
    INPUT:
        basename of a file (str)
    OUTPUT:
        'POLYGON', 'POLYLINE', 'POINT' or '' (str)
    '''
    
    while isInt(name[-1]) == True:
        name = name[:-1]
    if name[-1] == 'a':
        geomType = 'POLYGON'
    elif name[-1] == 'b' or name[-1] == 'f' or name[-1] == 'i' or name[-1] == 'l':
        geomType = 'POLYLINE'
    elif name[-1] == 'p':
        geomType = 'POINT'
    else:
        geomType = ''
    return geomType



def addFieldsToTable(folder, filesContainer, fileName, propertiesList):
    '''Adds fields to dtable or shapetable extracted from propertiesList
        if they are in the list matched with concrete filename

        INPUTS:
            folder (str) - folder, containing a file
            filesContainer (dict) - info about a file,
                key - filename in format 'base.exp',
                value - tuple with field names of table in right order
            fileName (str) - filename in format 'base.exp'
            propertiesList (list) - list with all possible properties, where each elem of list -
                tuple[0] - str name of a property, tuple[1:] - its properties
        OUTPUTS:
            None
        '''
    
    for value in filesContainer[fileName]:
        for propSet in propertiesList:
            if value == propSet[0].upper():
                AddField_management(*(folder + '\\' + fileName,) + propSet)




def createFile(folder, filesContainer, addFields, propertiesList):
    '''Creates shapefile or dtable in specified folder

    INPUTS:
        see addFieldsToTable()
        addFields (bool) - if True - adds fields to table, if False - doesn't add
    OUTPUTS:
        None
    '''
    
    for fileName in filesContainer:
        baseName = fileName.split('.')[0]
        extName = fileName.split('.')[1]
        if extName == 'dbf':
            CreateTable_management(folder + '\\', fileName)
            if addFields:
                addFieldsToTable(folder, filesContainer, fileName, propertiesList)
                DeleteField_management(folder + '\\' + fileName, 'Field1')
            AddMessage('Creating dbf-table: ' + folder + '\\' + fileName)
        elif extName == 'shp':
            if len(filesContainer[fileName]) > 0 and filesContainer[fileName][-1] == 'noSpatRef':
                SPAT_REF = ''
            elif fileName == 'dopl.shp':
                SPAT_REF = ''
            else:
                SPAT_REF = spatRef
            CreateFeatureclass_management(folder + '\\', baseName, defineGeometry(baseName), '', '', '', SPAT_REF)
            if addFields:
                for propSet in propertiesList:
                    if propSet[0] == 'L_code' and fileName != 'sectp.shp' and fileName != 'nsectp.shp' and fileName != 'druda.shp' and fileName != 'drudl.shp':
                        AddField_management(*(folder + '\\' + fileName,) + propSet)
                addFieldsToTable(folder, filesContainer, fileName, attrTablPropList)
            AddMessage('Creating shp-file: ' + folder + '\\' + fileName)



def createFolder(root, folder, addFields, propertiesList):
    '''Iteratively creates standard folders with user defined names

    INPUTS:
        see addFieldsToTable()
        root (str) - head folder, defined by user, where other folders are inserted
        folder (list) - main iterative list with all inserted foldernames and filenames,
            folder[0] - name of a directory, folder[1:] - names of inserted directories
    OUTPUTS:
        None
    '''
        
    name = folder[0]
    if root[-1] == '\\':
        root = root + name.upper()
    else:
        root = root + '\\' + name.upper()
    mkdir(root)
    
    for field in folder[1:]:
        
        if isinstance(field, list):
            createFolder(root, field, addFields, propertiesList)
            AddMessage('Creating folder: ' + root + '\\' + field[0].upper())

        elif isinstance(field, dict):
            createFile(root, field, addFields, propertiesList)





#-------------------PARAMETERS-----------------------------------------------------


root = GetParameterAsText(0)
zoneName = GetParameterAsText(1)
sheetNum1000 = str(GetParameterAsText(2))
sheetNum200 = str(GetParameterAsText(3))

if int(sheetNum200) == 0:
    sheetNum200 = ''
    


if GetParameterAsText(4) == 'true':
    addFields = True
else:
    addFields = False

# Adding one zero to the nomenclature name if it is less than 10
if len(sheetNum1000) == 1:
    sheetNum1000 = '0' + sheetNum1000
if len(sheetNum200) == 1:
    sheetNum200 = '0' + sheetNum200

# Creating base name which will be used for the main folders' names -> 1000 or 200
if sheetNum200:
    sheetNameLong = zoneName + '-' + sheetNum1000 + '-' + sheetNum200
    sheetNameShort = zoneName + sheetNum1000 + sheetNum200
else:
    sheetNameLong = zoneName + '-' + sheetNum1000
    sheetNameShort = zoneName + sheetNum1000


#Defining spatial reference
SR = ["GEOGCS['GCS_Pulkovo_1942',DATUM['D_Pulkovo_1942',SPHEROID['Krasovsky_1940',6378245.0,298.3]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]];",
    "-400 -400 11258999068426.2;",
    "-100000 10000;",
    "-100000 10000;",
    "8.98300073344349E-09;",
    "0.001;0.001;",
    "IsHighPrecision"]
newSR = ''

for i in SR:
    newSR += i

spatRef = SpatialReference()
spatRef.loadFromString(newSR)


#---------------------------------------------------------------------------------





    
# List of all possible properties that are could be found in table of GGK-set
#   in each item in list:
#       item[0] - name of a table field
#       item[1:] - properties of this field
attrTablPropList = [
    ('Az_pad', 'FLOAT', 6, 1),
    ('Azimut', 'FLOAT', 6, 1),
    ('Ug_pad', 'FLOAT', 6, 1),
    ('Abs', 'LONG'),
    ('B_code', 'LONG'),
    ('Dep', 'LONG'),
    ('Future', 'LONG'),
    ('God', 'LONG'),
    ('Id_Obj', 'LONG'),
    ('IdC', 'LONG'),
    ('IdD', 'LONG'),
    ('IdD1', 'LONG'),
    ('IdD2', 'LONG'),
    ('IdT', 'LONG'),
    ('IntN', 'LONG'),
    ('Krap', 'LONG'),
    ('L_code', 'LONG'),
    ('L_codeA', 'LONG'),
    ('L_codeL', 'LONG'),
    ('L_codeP', 'LONG'),
    ('Link', 'LONG'),
    ('Mark', 'LONG'),
    ('N', 'LONG'),
    ('N_line', 'LONG'),
    ('N_point', 'LONG'),
    ('Nstat', 'LONG'),
    ('Rang', 'LONG'),
    ('RangP', 'LONG'),
    ('S', 'LONG'),
    ('T', 'LONG'),
    ('Date', 'LONG'),
    ('Factor', 'SHORT'),
    ('Factor1', 'SHORT'),
    ('FactorG', 'SHORT'),
    ('IdF', 'SHORT'),
    ('IstD', 'SHORT'),
    ('TypeF', 'SHORT'),
    ('Age', 'TEXT', '', '', 32), 
    ('AgeE', 'TEXT', '', '', 32), 
    ('AgeM', 'TEXT', '', '', 32), 
    ('Ampl_h', 'TEXT', '', '', 16), 
    ('Ampl_t', 'TEXT', '', '', 16), 
    ('Ampl_v', 'TEXT', '', '', 16), 
    ('Author', 'TEXT', '', '', 128), 
    ('Avt', 'TEXT', '', '', 64), 
    ('Categ', 'TEXT', '', '', 16), 
    ('Comm', 'TEXT', '', '', ), 
    ('Ed_izm', 'TEXT', '', '', 16), 
    ('Gen', 'TEXT', '', '', 16), 
    ('Gen_type', 'TEXT', '', '', 128), 
    ('Geol_form', 'TEXT', '', '', 128), 
    ('Gname', 'TEXT', '', '', 64), 
    ('Gorizont', 'TEXT', '', '', 64), 
    ('Grad', 'TEXT', '', '', 16), 
    ('GTO', 'TEXT', '', '', 128), 
    ('H', 'TEXT', '', '', 16),
    ('H_skv', 'TEXT', '', '', 16), 
    ('HK', 'TEXT', '', '', 16), 
    ('HP', 'TEXT', '', '', 16), 
    ('Hq', 'TEXT', '', '', 16), 
    ('Index', 'TEXT', '', '', 128),
    ('IndexP', 'TEXT', '', '', 32),
    ('IndexQ', 'TEXT', '', '', 32), 
    ('IndexS', 'TEXT', '', '', 32), 
    ('IndexZ', 'TEXT', '', '', 32),
    ('Interval', 'TEXT', '', '', 32),
    ('Isk', 'TEXT', '', '', 16), 
    ('List', 'TEXT', '', '', 32), 
    ('Longitude', 'TEXT', '', '', 16), 
    ('M', 'TEXT', '', '', 16),
    ('Map', 'TEXT', '', '', 16),
    ('Megazona', 'TEXT', '', '', 128), 
    ('Metod', 'TEXT', '', '', 32), 
    ('Mgn', 'TEXT', '', '', 16), 
    ('Min', 'TEXT', '', '', 16), 
    ('MP', 'TEXT', '', '', 16), 
    ('Name', 'TEXT', '', '', ), 
    ('Name1', 'TEXT', '', '', ), 
    ('Name2', 'TEXT', '', '', ), 
    ('Name3', 'TEXT', '', '', ), 
    ('Name4', 'TEXT', '', '', ), 
    ('NameG', 'TEXT', '', '', 64), 
    ('Nceil', 'TEXT', '', '', 128),
    ('N_type', 'TEXT', '', '', 128),
    ('Okr', 'TEXT', '', '', 64), 
    ('Org', 'TEXT', '', '', 64), 
    ('Otdel', 'TEXT', '', '', 64), 
    ('P', 'TEXT', '', '', 16), 
    ('P1', 'TEXT', '', '', 16), 
    ('P2', 'TEXT', '', '', 16), 
    ('P3', 'TEXT', '', '', 16), 
    ('PDK', 'TEXT', '', '', 16), 
    ('Pers_nad', 'TEXT', '', '', 16), 
    ('Podzona', 'TEXT', '', '', 64), 
    ('Rayon', 'TEXT', '', '', 128), 
    ('ResO', 'TEXT', '', '', 32), 
    ('Resours', 'TEXT', '', '', 16), 
    ('ResP', 'TEXT', '', '', 32), 
    ('Rud_form', 'TEXT', '', '', 128), 
    ('Scale', 'TEXT', '', '', 32), 
    ('Stage', 'TEXT', '', '', 64), 
    ('Sub', 'TEXT', '', '', 64), 
    ('Substage', 'TEXT', '', '', 64), 
    ('System', 'TEXT', '', '', 64), 
    ('T_point', 'TEXT', '', '', 16), 
    ('Tdef', 'TEXT', '', '', 128),
    ('Text', 'TEXT', '', '', ),
    ('Text1', 'TEXT', '', '', ), 
    ('Text2', 'TEXT', '', '', ), 
    ('Text3', 'TEXT', '', '', ), 
    ('Text4', 'TEXT', '', '', ), 
    ('Text5', 'TEXT', '', '', ),
    ('TMC', 'TEXT', '', '', ),
    ('Tpetr', 'TEXT', '', '', 128),
    ('Tstrat', 'TEXT', '', '', 128),
    ('Txt', 'TEXT', '', '', 32), 
    ('V_leg', 'TEXT', '', '', 32), 
    ('Vid', 'TEXT', '', '', 128), 
    ('Vid_rab', 'TEXT', '', '', 128), 
    ('Year', 'TEXT', '', '', 8), 
    ('Z', 'TEXT', '', '', 32), 
    ('Zona', 'TEXT', '', '', 128), 
    ('Type', 'TEXT', '', '', 128)
]






# ECM folder
#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------


#   ecm\TOPO folder
#---------------------------------------------------------------------------------

hyps = ['hyps',
        {
        'hypsa.shp' : ('NAME',),
        'hypsl.shp' : ('TEXT', 'GRAD', 'MIN', 'LONGITUDE')
        }
        ]
phys = ['phys',
        {
        'physa.shp' : ('NAME',),
        'physb.shp' : (),
        'physl.shp': ('ABS',),
        'physp.shp' : ('ABS', 'NAME')
        }
        ]
dnet = ['dnet',
        {
        'dneta.shp' : ('NAME', 'TEXT',),
        'dnetb.shp' : (),
        'dneti.shp' : ('DEP',),
        'dnetl.shp' : ('NAME',),
        'dnetp.shp' : ('NAME', 'DEP', 'ABS', 'AZIMUT')
        }
        ]
pplc = ['pplc',
        {
        'pplca.shp' : ('NAME',),
        'pplcl.shp' : (),
        'pplcp.shp' : ('NAME',)
        }
        ]
road = ['road',
        {
        'roadl.shp' : ('TEXT',),
        'roadp.shp' : ('NAME', 'AZIMUT')
        }
        ]
polt = ['polt',
        {
        'polta1.shp' : ('OKR', 'SUB'),
        'polta2.shp' : ('OKR', 'SUB', 'AVT'),
        'poltl.shp' : ('SpatRef',),
        'poltp.shp' : ('OKR', 'SUB', 'AVT')
        }
        ]
fram = ['fram']

leg_topo = {'leg_topo.dbf' : ('L_CODE', 'B_CODE', 'TEXT1')}

topo200  = ['topo200', hyps, phys, dnet, pplc, road, polt, fram]
topo500  = ['topo500', hyps, phys, dnet, pplc, road, polt, fram]
topo1000 = ['topo1000', hyps, phys, dnet, pplc, road, polt, fram]
topo2500 = ['topo2500', hyps, phys, dnet, pplc, road, polt, fram]
topo5000 = ['topo5000', hyps, phys, dnet, pplc, road, polt, fram]
vrez = ['vrez']
rastr = ['rastr']

if sheetNum200:
    topo = ['topo', topo200, topo500, topo1000, vrez, rastr, leg_topo]
else:
    topo = ['topo', topo1000, topo2500, topo5000, vrez, rastr, leg_topo]

#---------------------------------------------------------------------------------



#   ecm\GEOL folder
#---------------------------------------------------------------------------------

base = ['base',
        {
        'basea.shp' : ('KRAP', 'TDEF', 'IDD1', 'FACTOR', 'FACTOR1'),
        'baseb.shp' : ('TDEF', 'IDD2', 'FACTOR'),
        'basef.shp' : ('FACTOR',),
        'basel.shp' : ('TDEF', 'IDD1', 'FACTOR'),
        'basep.shp' : ('TDEF', 'AZIMUT', 'IDD1', 'FACTOR'),
        'based1.dbf' : ('IDD1', 'MARK', 'N', 'NCEIL', 'TPETR', 'NAME', 'ID_OBJ'),
        'based2.dbf' : ('IDD2', 'AZ_PAD', 'UG_PAD', 'AMPL_V', 'AMPL_H', 'AMPL_T', 'AGE')
        }
        ]
over = ['over',
        {
        'overa.shp' : ('H', 'TDEF', 'FACTOR'),
        'overb.shp' : ('TDEF', 'FACTOR'),
        'overl.shp' : ('H', 'TDEF', 'FACTOR')
        }
        ]
rmet = ['rmet',
        {
        'rmeta.shp' : ('FACTOR',),
        'rmeta1.shp' : ('AGE', 'FACTOR'),
        'rmetb.shp' : ('INDEX', 'FACTOR')
        }
        ]
altr = ['altr',
        {
        'altra.shp' : ('NAME', 'INDEX', 'AGE', 'FACTOR'),
        'altrf.shp' : ('FACTOR',),
        'altrb.shp' : ('FACTOR',),
        'altrl.shp' : ('NAME', 'INDEX', 'AGE', 'FACTOR'),
        'altrp.shp' : ('NAME', 'INDEX', 'AGE', 'FACTOR')
        }
        ]
volc = ['volc',
        {
        'volca.shp' : ('FACTOR',),
        'volcp.shp' : ('DATE', 'MGN', 'FACTOR')
        }
        ]
bedd = ['bedd',
        {
        'beddp.shp' : ('UG_PAD', 'AZIMUT')
        }
        ]
strc = ['strc',
        {
        'strca.shp' : ('TDEF', 'FACTOR'),
        'strcb.shp' : ('TDEF', 'FACTOR'),
        'strcl.shp' : ('TDEF', 'FACTOR')
        }
        ]
isln = ['isln',
        {
        'islnl.shp': ('Z', 'FACTOR')
        }
        ]
oobs = ['oobs',
        {
        'oobsl.shp' : ('N', 'NCEIL', 'NAME', 'INDEXS', 'LINK', 'ID_OBJ'),
        'oobsp.shp' : ('N', 'NCEIL', 'NAME', 'H_SKV', 'HQ', 'INDEXS', 'INDEXZ', 'INDEXQ', 'LINK', 'ID_OBJ')
        }
        ]
robs = ['robs',
        {
        'robsp.shp' : ('LINK', 'N', 'NCEIL', 'P', 'AGE', 'AGEE', 'AGEM', 'HQ', 'ID_OBJ')
        }
        ]
tech = ['tech',
        {
        'techa.shp' : ('FACTOR',),
        'techp.shp' : ('FACTOR',)
        }
        ]
drud = ['drud',
        {
        'druda.shp' : ('L_CODEA', 'NAME', 'IDT', 'N', 'NCEIL', 'IDC', 'L_CODE', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'L_CODEP', 'RESO', 'RESP', 'IDD', 'H', 'FACTOR', 'ID_OBJ'),
        'drudi.shp' : ('Z', 'FACTOR', 'INTN'),
        'drudl.shp' : ('L_CODEL', 'NAME', 'IDT', 'N', 'NCEIL', 'IDC', 'L_CODE', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'L_CODEP', 'RESO', 'RESP', 'IDD', 'H', 'FACTOR', 'ID_OBJ'),
        'drudp.shp' : ('NAME', 'N', 'NCEIL', 'IDC', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'L_CODEP', 'RESO', 'RESP', 'IDD', 'H', 'FACTOR', 'ID_OBJ'),
        'drudt.dbf' : ('IDT', 'NAME', 'N', 'NCEIL', 'IDC', 'L_CODE', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'L_CODEP', 'RESO', 'RESP', 'IDD', 'FACTOR', 'ID_OBJ'),
        'drudc.dbf' : ('IDC', 'L_CODE', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'L_CODEP', 'RESO', 'RESP', 'IDD'),
        'drudd.dbf' : ('IDD', 'N_TYPE', 'CATEG', 'ED_IZM', 'RESOURS')
         }
        ]
dplc = ['dplc',
        {
        'dplca.shp' : ('NAME', 'IDT', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'RANGP', 'RESO', 'RESP', 'IDD', 'H', 'FACTOR', 'ID_OBJ'),
        'dplcb.shp' : (),
        'dplcl.shp' : ('NAME', 'IDT', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'RANGP', 'RESO', 'RESP', 'IDD', 'H', 'FACTOR', 'ID_OBJ'),
        'dplcp.shp' : ('NAME', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'AZIMUT', 'RANGP', 'RESO', 'RESP', 'IDD', 'H', 'FACTOR', 'ID_OBJ'),
        'dplct.dbf' : ('IDT', 'L_CODE', 'NAME', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'RANGP', 'RESO', 'RESP', 'IDD', 'FACTOR', 'ID_OBJ'),
        'dplcd.dbf' : ('IDD', 'N_TYPE', 'CATEG', 'ED_IZM', 'RESOURS')
        }
        ]
pann = ['pann',
        {
        'panna.shp' : ('N', 'NCEIL', 'LIST', 'FACTOR', 'ID_OBJ'),
        'pannl.shp' : ('N', 'NCEIL', 'LIST', 'FACTOR', 'ID_OBJ'),
        'pannp.shp' : ('N', 'NCEIL', 'LIST', 'FACTOR', 'ID_OBJ')
        }
        ]
chem = ['chem',
        {
        'chema.shp' : ('N', 'NCEIL', 'LIST', 'FACTOR', 'ID_OBJ'),
        'cheml.shp' : ('N', 'NCEIL', 'LIST', 'FACTOR', 'ID_OBJ'),
        'chemp.shp' : ('N', 'NCEIL', 'LIST', 'FACTOR', 'ID_OBJ')
        }
        ]
fys  = ['phys',
        {
        'physa.shp' : ('N', 'NCEIL', 'H', 'METOD', 'ISK', 'MARK', 'FACTOR', 'ID_OBJ'),
        'physl.shp' : ('N', 'NCEIL', 'H', 'METOD', 'ISK', 'MARK', 'FACTOR', 'ID_OBJ'),
        'physp.shp' : ('N', 'NCEIL', 'H', 'METOD', 'ISK', 'MARK', 'FACTOR', 'ID_OBJ')
        }
        ]

mran_usl = ['mran_usl']
prog_usl = ['prog_usl']
mran = ['mran',
        {
        'mrana1.shp' : ('INDEX', 'NAME'),
        'mrana2.shp' : ('NAME', 'INDEX', 'IDD', 'PERS_NAD', 'VID_RAB'),
        'mrana3.shp' : ('NAME', 'INDEX', 'IDD', 'PERS_NAD', 'VID_RAB'),
        'mrana4.shp' : ('NAME', 'INDEX', 'IDD', 'PERS_NAD', 'VID_RAB'),
        'mrana5.shp' : ('NAME', 'INDEX', 'IDD', 'PERS_NAD', 'VID_RAB'),
        'mrana6.shp' : ('NAME', 'INDEX', 'IDD', 'L_CODEP', 'PERS_NAD', 'VID_RAB'),
        'mrand.dbf' : ('IDD', 'N_TYPE', 'ED_IZM', 'P1', 'P2', 'P3', 'MP')
        },
        mran_usl,
        prog_usl
        ]
mfa2 = ['mfa2',
        {
        'mfa2a.shp' : ('COMM',),
        'mfa2b.shp' : (),
        'mfa2l.shp' : ('COMM',),
        'mfa2p.shp' : ('COMM',)
        }
        ]
mfa3 = ['mfa3',
        {
        'mfa3a.shp' : ('COMM',),
        'mfa3b.shp' : ()
        }
        ]
sect = ['sect',
        {
        'sectl.shp' : ('N_LINE', 'TEXT'),
        'sectp.shp' : ('N_LINE', 'N_POINT', 'T_POINT')    # l_code 
        }
        ]

ramr = ['ramr',
        {
        'ramrl.shp' : ('noSpatRef',),
        'ramrp.shp' : ('H', 'noSpatRef')
        }
        ]
link = ['link',
        {
        'linkp.shp' : ('N_LINE', 'N_POINT', 'T_POINT', 'noSpatRef')
        }
        ]
gnam = ['gnam',
        {
        'gnamp.shp' : ('GNAME', 'noSpatRef')
        }
        ]
gphys = ['gphys',
         {
         'gphysl.shp' : ('TXT','noSpatRef'),
         'gphysp.shp' : ('H','noSpatRef')
         }
         ]
hole = ['hole',
        {
        'holel.shp' : ('N','noSpatRef')
        }
        ]
base_s = ['base', {
        'basea.shp' : ('KRAP', 'TDEF', 'IDD1', 'FACTOR', 'FACTOR1', 'noSpatRef'),
        'baseb.shp' : ('TDEF', 'IDD2', 'FACTOR', 'noSpatRef'),
        'basef.shp' : ('FACTOR', 'noSpatRef'),
        'basel.shp' : ('TDEF', 'IDD1', 'FACTOR', 'noSpatRef')}]
rmet_s = ['rmet',
          {
        'rmeta.shp' : ('AGE', 'FACTOR', 'noSpatRef'),
        'rmetb.shp' : ('INDEX', 'FACTOR', 'noSpatRef'),
        'rmetl.shp' : ('noSpatRef',)
        }
          ]
altr_s = ['altr',
          {
        'altra.shp' : ('NAME', 'INDEX', 'AGE', 'FACTOR', 'noSpatRef'),
        'altrf.shp' : ('FACTOR', 'noSpatRef'),
        'altrb.shp' : ('FACTOR', 'noSpatRef'),
        'altrl.shp' : ('NAME', 'INDEX', 'AGE', 'FACTOR', 'noSpatRef')
        }
          ]
geols = ['geols', ramr, link, gnam, gphys, base_s, rmet_s, altr_s, hole]

gk_usl = ['gk_usl',
            {
            'gk_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'FACTOR', 'noSpatRef'),
            'gk_usll.shp' : ('INDEX', 'NAME', 'FACTOR', 'noSpatRef'),
            'gk_uslp.shp' : ('INDEX', 'NAME', 'AZIMUT', 'FACTOR', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]
pi_usl = ['pi_usl',
            {
            'pi_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'FACTOR', 'noSpatRef'),
            'pi_usll.shp' : ('INDEX', 'NAME', 'FACTOR', 'noSpatRef'),
            'pi_uslp.shp' : ('INDEX', 'NAME', 'AZIMUT', 'FACTOR','noSpatRef'),
            'dopl.shp' : ()
            }
            ]
strat = ['strat',
         {
         'strata.shp' : ('KRAP', 'M', 'IDT', 'noSpatRef'),
         'stratb.shp' : ('noSpatRef',),
         'stratl.shp' : ('noSpatRef',),
         'stratp.shp' : ('noSpatRef',),
         'stratd.shp' : ('noSpatRef',),
         'dopl.shp' : (),
         'stratt.dbf' : ('IDT', 'SYSTEM', 'OTDEL', 'STAGE', 'SUBSTAGE', 'GORIZONT', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')
         }
         ]
tabl_pi  = ['tabl_pi',
            {
            'pi_druda.shp' : ('L_CODEA', 'RANG', 'INDEX', 'GEN_TYPE', 'RUD_FORM', 'noSpatRef'),
            'pi_drudl.shp' : ('L_CODEL', 'RANG', 'INDEX', 'GEN_TYPE', 'RUD_FORM', 'noSpatRef'),
            'pi_drudp.shp' : ('RANG', 'INDEX', 'GEN_TYPE', 'RUD_FORM', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]

m_base = ['m_base',
          {
          'm_basea.shp' : ('KRAP', 'INDEX', 'RUD_FORM', 'GEOL_FORM', 'GTO', 'TMC', 'noSpatRef'),
          'm_baseb.shp' : ('noSpatRef',),
          'm_basel.shp' : ('noSpatRef',),
          'm_basep.shp' : ('noSpatRef',)
          }
          ]
m_drud = ['m_drud',
          {
          'm_druda.shp' : ('INDEX', 'GEN_TYPE', 'noSpatRef'),
          'm_drudl.shp' : ('L_CODEL', 'RANG', 'INDEX', 'GEN_TYPE', 'RUD_FORM', 'noSpatRef'),
          'm_drudp.shp' : ('INDEX', 'GEN_TYPE', 'RUD_FORM', 'noSpatRef')
          }
          ]
m_altr = ['m_altr',
          {
          'm_altra.shp' : ('INDEX', 'AGE', 'noSpatRef'),
          'm_altrb.shp' : ('noSpatRef',),
          'm_altrl.shp' : ('INDEX', 'AGE', 'noSpatRef'),
          'm_altrp.shp' : ('INDEX', 'AGE', 'noSpatRef')
          }
          ]
minr = ['minr',
        m_base,
        m_drud,
        m_altr,
        {'dopl.shp' : ()}
        ]

smr_usl = ['smr_usl',
           ['mran',
            {'mrana.shp' : ('NAMEG', 'NAME', 'INDEX', 'noSpatRef')}
            ],
           m_drud
           ]

drud_ = ['drud',
          {
          'druda.shp' : ('INDEX', 'GEN_TYPE', 'L_CODEP', 'RANGP', 'RESO', 'RESP', 'IDD', 'noSpatRef'),
          'drudl.shp' : ('L_CODEL', 'RANG', 'INDEX', 'GEN_TYPE', 'RUD_FORM', 'L_CODEP', 'RANGP', 'RESO', 'RESP', 'IDD', 'noSpatRef'),
          'drudp.shp' : ('INDEX', 'GEN_TYPE', 'RUD_FORM', 'L_CODEP', 'RANGP', 'RESO', 'RESP', 'IDD', 'noSpatRef'),
          'drudd.dbf' : ('IDD', 'N_TYPE', 'CATEG', 'ED_IZM', 'RESOURS')
          }
          ]
reks = ['reks',
        {'reksa.shp' : ('TEXT', 'noSpatRef')}
        ]
sppi_usl = ['sppi_usl',
            ['mran',
             {
              'mrana.shp' : ('NAMEG', 'NAME', 'INDEX', 'noSpatRef'),
              'mrand.dbf' : ('IDD', 'N_TYPE', 'ED_IZM', 'P1', 'P2', 'P3', 'MP', 'noSpatRef')
              }
             ],
            drud_,
            reks
            ]

leg_geol = {'leg_geol.dbf' : ('L_CODE', 'B_CODE', 'IDF', 'TYPEF', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4', 'TEXT5')}

mt_geol = {'mt_geol.dbf' : ('IDF', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')}


if sheetNum200:
    geol = ['geol', base, over, rmet, altr, volc, bedd, strc, isln, oobs, robs, tech,
        drud, dplc, pann, chem, fys, mran, mfa2, mfa3, sect, geols, vrez, gk_usl,
        strat, pi_usl, tabl_pi, minr, smr_usl, sppi_usl, leg_geol, mt_geol]
else:
    geol = ['geol', base, over, rmet, altr, volc, strc, isln, oobs, robs, tech,
        drud, dplc, pann, chem, fys, mran, mfa2, mfa3, sect, geols, vrez, gk_usl,
        strat, pi_usl, tabl_pi, minr, smr_usl, sppi_usl, leg_geol, mt_geol]
#---------------------------------------------------------------------------------



#   ecm\QUART folder
#---------------------------------------------------------------------------------

hice = ['hice',
        {
        'hicea.shp' : ()
        }
        ]
glac = ['glac',
        {
        'glaca.shp' : ('FACTORG',),
        'glacp.shp' : ('FACTORG',)
        }
        ]
fros = ['fros',
        {
        'frosa.shp' : (),
        'frosb.shp' : (),
        'frosp.shp' : ('HK', 'HP')
        }
        ]
covr = ['covr',
        {
        'covra.shp' : ()
        }
        ]
gran = ['gran',
        {
        'grana.shp' : (),
        'granb.shp' : ()
        }
        ]
gmran = ['gmran',
         {
         'gmrana1.shp' : ('INDEX', 'NAME'),
         'gmrana2.shp' : ('INDEX', 'NAME'),
         'gmrana3.shp' : ('INDEX', 'NAME'),
         'gmranb.shp' : ('TDEF',)
         }
         ]
morp = ['morp',
        {
        'morpa1.shp' : ('NAME', 'FACTORG'),
        'morpf1.shp' : ('FACTORG',),
        'morpb.shp' : ('FACTORG',),
        'morpl.shp' : ('NAME', 'FACTORG'),
        'morpp.shp' : ('NAME', 'AZIMUT', 'FACTORG')
        }
        ]
exod = ['exod',
        {
        'exodp.shp' : ('AZIMUT', 'FACTORG')
        }
        ]
palg = ['palg',
        {
        'palgl.shp' : ('NAME', 'FACTORG'),
        'palgp.shp' : ('NAME', 'AZIMUT', 'FACTORG')
        }
        ]
lift = ['lift',
        {
        'liftl0.shp' : ('H', 'NAME', 'FACTORG')
        }
        ]
qobs = ['qobs',
        {
        'qobsl.shp' : ('H',),
        'qobsp.shp' : ('LINK', 'N', 'NCEIL', 'P', 'AGE', 'AGEE', 'AGEM', 'HQ', 'ID_OBJ')
        }
        ]

hice_quarts = ['hice',
        {
        'hicea.shp' : ('noSpatRef',)
        }
        ]
quarts = ['quarts', ramr, link, gnam, base_s, altr_s, hole, hice_quarts]

drud_s = ['drud',
         {
         'drudp.shp' : ('N_TYPE', 'INDEX', 'GEN_TYPE', 'RUD_FORM')
         }
         ]
dplc_s = ['dplc',
          {
         'dplcp.shp' : ('RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'AZIMUT', 'noSpatRef')
          }
          ]

qrel = ['qrel', ramr, link, base_s, drud_s, dplc_s]

q_usl = ['q_usl',
             {
             'q_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'noSpatRef'),
             'q_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
             'q_uslp.shp' : ('INDEX', 'NAME', 'AZIMUT', 'noSpatRef'),
             'dopl.shp' : ()
             }
             ]
gmf_usl = ['morf_usl',
            {
            'gmf_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'noSpatRef'),
            'gmf_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'gmf_uslp.shp' : ('INDEX', 'NAME', 'AZIMUT', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]

sh_kor = ['sh_kor']

leg_quart = {'leg_quart.dbf' : ('L_CODE', 'B_CODE', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')}


if sheetNum200:
    quart = ['quart', base, over, altr, bedd, hice, glac, fros, covr, gran,
         gmran, morp, exod, palg, lift, oobs, qobs, sect, quarts, qrel,
         q_usl, gmf_usl, sh_kor, leg_quart]
else:
    quart = ['quart', base, over, altr, hice, glac, fros, covr, gran,
         gmran, morp, exod, palg, lift, oobs, qobs, sect, quarts, qrel,
         q_usl, gmf_usl, sh_kor, leg_quart]
#---------------------------------------------------------------------------------



#   ecm\INT folder
#---------------------------------------------------------------------------------

erkp = ['erkp',
        {
        'erkpl.shp' : ('ABS',),
        'erkpp.shp' : ('ABS',)
        }
        ]


INT = ['int', base, rmet, altr, erkp, isln, oobs, robs, drud, mran, mfa2, mfa3, sect, vrez]

#---------------------------------------------------------------------------------



#   ecm\BOTT folder
#---------------------------------------------------------------------------------

gent = ['gent',
        {
        'genta.shp' : (),
        'gentb.shp' : ()
         }
        ]
lits = ['lits',
        {
        'litsa.shp' : (),
        'litsb.shp' : ()
        }
        ]
sedm = ['sedm',
        {
        'sedma.shp' : ('TDEF',),
        'sedmp.shp' : ('TDEF',)
        }
        ]
morp_bott = ['morp',
        {
        'morpa1.shp' : ('NAME', 'FACTORG'),
        'morpf1.shp' : ('FACTORG',),
        'morpl.shp' : ('NAME', 'FACTORG'),
        'morpp.shp' : ('NAME', 'AZIMUT', 'FACTORG')
        }
        ]
dinm = ['dinm',
        {
        'dinma.shp' : ('TDEF',),
        'dinml.shp' : ('TDEF',),
        'dinmp.shp' : ('TDEF', 'AZIMUT')
        }
        ]
volc_bott = ['volc',
        {
        'volca.shp' : (),
        'volcp.shp' : ('DATE', 'MGN')
        }
        ]
dplc_bott = ['dplc',
        {
        'dplca.shp' : ('NAME', 'IDT', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'RANGP', 'RESO', 'RESP', 'IDD', 'H', 'ID_OBJ'),
        'dplcl.shp' : ('NAME', 'IDT', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'RANGP', 'RESO', 'RESP', 'IDD', 'H', 'ID_OBJ'),
        'dplcp.shp' : ('NAME', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'AZIMUT', 'RANGP', 'RESO', 'RESP', 'IDD', 'H', 'ID_OBJ'),
        'dplct.dbf' : ('IDT', 'L_CODE', 'NAME', 'N', 'NCEIL', 'RANG', 'INDEX', 'N_TYPE', 'GEN_TYPE', 'RUD_FORM', 'NSTAT', 'RANGP', 'RESO', 'RESP', 'IDD', 'ID_OBJ'),
        'dplcd.dbf' : ('IDD', 'N_TYPE', 'CATEG', 'ED_IZM', 'RESOURS')
        }
        ]
pann_bott = ['pann',
        {
        'panna.shp' : ('N', 'NCEIL', 'LIST', 'ID_OBJ'),
        'pannl.shp' : ('N', 'NCEIL', 'LIST', 'ID_OBJ'),
        'pannp.shp' : ('N', 'NCEIL', 'LIST', 'ID_OBJ')
        }
        ]
chem_bott = ['chem',
        {
        'chema.shp' : ('N', 'NCEIL', 'LIST', 'ID_OBJ'),
        'cheml.shp' : ('N', 'NCEIL', 'LIST', 'ID_OBJ'),
        'chemp.shp' : ('N', 'NCEIL', 'LIST', 'ID_OBJ')
        }
        ]
gazg = ['gazg',
        {
        'gazgl.shp' : ('TDEF',),
        'gazgp.shp' : ('LIST',)
        }
        ]
isln_bott = ['isln',
        {
        'islnl.shp': ('Z',)
        }
        ]
tech_bott = ['tech',
        {
        'techa.shp' : (),
        'techl.shp' : (),
        'techp.shp' : ()
        }
        ]
oobs_bott = ['oobs',
        {
        'oobsp.shp' : ('TDEF',)
        }
        ]

leg_bott = {'leg_bott.dbf' : ('L_CODE', 'B_CODE', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')}

bott = ['bott', gent, lits, sedm, morp_bott, dinm, volc_bott, fros, dplc_bott,
        pann_bott, chem_bott, gazg, isln_bott, tech_bott, oobs_bott, leg_bott]

#---------------------------------------------------------------------------------



#   ecm\TECT folder
#---------------------------------------------------------------------------------

base_tect = ['base',
        {
        'basea.shp' : ('KRAP', 'INDEX', 'NAME'),
        'baseb.shp' : ('INDEX', 'NAME'),
        'basel.shp' : ('INDEX', 'NAME'),
        'basep.shp' : ('INDEX', 'NAME'),
        }
        ]
morf = ['morf',
        {
        'morfa1.shp' : ('INDEX', 'NAME'),
        'morfl.shp' : ('INDEX', 'NAME'),
        'morfp.shp' : ('INDEX', 'NAME')
        }
        ]
isln_tect = ['isln',
        {
        'islnl.shp': ('Z',)
        }
        ]
tran = ['tran',
        {
        'trana0.shp' : ('INDEX', 'NAME'),
        'trana1.shp' : ('INDEX', 'NAME'),
        'trana2.shp' : ('INDEX', 'NAME'),
        'trana3.shp' : ('INDEX', 'NAME'),
        'tranb.shp' : ('TDEF',)
        }
        ]
fran = ['fran',
        {
        'frana0.shp' : ('INDEX', 'NAME'),
        'frana1.shp' : ('INDEX', 'NAME'),
        'frana2.shp' : ('INDEX', 'NAME'),
        'frana3.shp' : ('INDEX', 'NAME'),
        'franb.shp' : ('TDEF',)
        }
        ]
pran = ['pran',
        {
        'prana0.shp' : ('INDEX', 'NAME'),
        'prana1.shp' : ('INDEX', 'NAME'),
        'prana2.shp' : ('INDEX', 'NAME'),
        'prana3.shp' : ('INDEX', 'NAME'),
        'pranb.shp' : ('TDEF',)
        }
        ]
nran = ['nran',
        {
        'nrana0.shp' : ('INDEX', 'NAME'),
        'nrana1.shp' : ('INDEX', 'NAME'),
        'nrana2.shp' : ('INDEX', 'NAME'),
        'nrana3.shp' : ('INDEX', 'NAME'),
        'nranb.shp' : ('TDEF',)
        }
        ]
tect_usl = ['tect_usl',
            {
            'tect_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'noSpatRef'),
            'tect_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'tect_uslp.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]
tran_usl = ['tran_usl',
            {
            'tran_usla.shp' : ('INDEX', 'NAME1', 'NAME2', 'NAME3', 'NAME4', 'noSpatRef'),
            'tran_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'tran_uslp.shp' : ('INDEX', 'NAME', 'noSpatRef')
            }
            ]
fran_usl = ['fran_usl',
            {
            'fran_usla.shp' : ('INDEX', 'NAME1', 'NAME2', 'NAME3', 'NAME4', 'noSpatRef'),
            'fran_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'fran_uslp.shp' : ('INDEX', 'NAME', 'noSpatRef')
            }
            ]
pran_usl = ['pran_usl',
            {
            'pran_usla.shp' : ('INDEX', 'NAME1', 'NAME2', 'NAME3', 'NAME4', 'noSpatRef'),
            'pran_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'pran_uslp.shp' : ('INDEX', 'NAME', 'noSpatRef')
            }
            ]
nran_usl = ['nran_usl',
            {
            'nran_usla.shp' : ('INDEX', 'NAME1', 'NAME2', 'NAME3', 'NAME4', 'noSpatRef'),
            'nran_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'nran_uslp.shp' : ('INDEX', 'NAME', 'noSpatRef')
            }
            ]

leg_tect = {'leg_tect.dbf' : ('L_CODE', 'B_CODE', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')}

tect = ['tect', base_tect, morf, isln_tect, tran, fran, pran, nran, tect_usl,
        tran_usl, fran_usl, pran_usl, nran_usl, leg_tect]

#---------------------------------------------------------------------------------



#   ecm\ECOL folder
#---------------------------------------------------------------------------------

tabl_land = ['tabl_land',
             {
             'tabl_landa.shp' : (),
             'dopl.shp' : ()
             }
            ]
land = ['land',
        {
        'landa.shp' : ('KRAP',),
        'landb.shp' : (),
        },
        tabl_land
        ]
seys = ['seys',
        {
        'seysa.shp' : ('S',),
        'seysb.shp' : (),
        'seysl.shp' : (),
        'seysp.shp' : ('S', 'GOD')
        }
        ]
volc_ecol = ['volc',
        {
        'volca.shp' : (),
        'volcl.shp' : (),
        'volcp.shp' : ()
        }
        ]
ekzo = ['ekzo',
        {
        'ekzoa.shp' : (),
        'ekzol.shp' : (),
        'ekzop.shp' : ('AZIMUT',)
        }
        ]
tech_ecol = ['tech',
        {
        'techa.shp' : (),
        'techl.shp' : (),
        'techp.shp' : ()
        }
        ]
chem_ecol = ['chem',
        {
        'chema.shp' : ('LIST', 'GEN', 'PDK'),
        'cheml.shp' : ('LIST', 'GEN', 'PDK'),
        'chemp.shp' : ('LIST', 'GEN', 'PDK', 'AZIMUT')
        }
        ]

ggul_usl = ['ggul_usl',
            {
            'ggul_usla.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]
ggul = ['ggul',
        {
        'ggula1.shp' : (),
        'ggula2.shp' : (),
        'ggulb1.shp' : (),
        'ggulb2.shp' : ()
        }
        ]

sego_usl = ['sego_usl',
            {
            'sego_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]
sego = ['sego',
        sego_usl,
        {
        'segoa.shp' : ('FUTURE',),
        'segob.shp' : ()
        }
        ]

resv = ['resv',
        {
        'resva.shp' : ('NAME',),
        'resvl.shp' : ()
        }
        ]
rekm = ['rekm',
        {
        'rekma.shp' : ()
        }
        ]

pamp_usl = ['pamp_usl',
            {
            'pamp_uslp.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]
pamp = ['pamp',
        pamp_usl,
        {
        'pampp.shp' : ('N', 'TYPE')
        }
        ]

ecol_usl = ['ecol_usl',
            {
            'ecol_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'noSpatRef'),
            'ecol_usll.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'ecol_uslp.shp' : ('INDEX', 'NAME', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]

leg_ecol = {'leg_ecol.dbf' : ('L_CODE', 'B_CODE', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')}

ecol = ['ecol', land, seys, volc_ecol, ekzo, tech_ecol, chem_ecol, ggul, sego, resv,
        rekm, pamp, ecol_usl, leg_ecol]

#---------------------------------------------------------------------------------



#   ecm\MAGN folder
#---------------------------------------------------------------------------------

magn_magn = ['magn',
             {
             'magna.shp' : (),
             'magnl.shp' : ('Z',),
             'magnp.shp' : ('Z',)
             }
             ]

leg_magn = {'leg_magn.dbf' : ('L_CODE', 'B_CODE', 'TEXT1', 'TEXT2', 'TEXT3')}

magn = ['magn', magn_magn, leg_magn]

#---------------------------------------------------------------------------------



#   ecm\GRAV folder
#---------------------------------------------------------------------------------

grav_grav = ['grav',
             {
            'grava.shp' : (),
            'gravl.shp' : ('Z',),
            'gravp.shp' : ('Z',)
            }
             ]

leg_grav = {'leg_grav.dbf' : ('L_CODE', 'B_CODE', 'TEXT1', 'TEXT2', 'TEXT3')}

grav = ['grav', grav_grav, leg_grav]

#---------------------------------------------------------------------------------



# ecm\SFR folder
#---------------------------------------------------------------------------------

ind_base = ['ind_base',
            {
            'ind_basea.shp' : ('INDEX', 'RAYON', 'PODZONA', 'ZONA', 'MEGAZONA'),
            'ind_baseb.shp' : ('INDEX', 'TDEF')
            }
            ]

ind_sfr = ['ind_sfr',
           {
           'ind_sfra1.shp' : ('INDEX', 'NAME'),
           'ind_sfra2.shp' : ('INDEX', 'NAME'),
           'ind_sfra3.shp' : ('INDEX', 'NAME'),
           'ind_sfra4.shp' : ('INDEX', 'NAME')
           },
           ind_base]

leg_sfr = {'leg_sfr.dbf' : ('L_CODE', 'B_CODE', 'TEXT1', 'TEXT2', 'TEXT3')}

sfr = ['sfr', ind_sfr, leg_sfr]

#---------------------------------------------------------------------------------



#   ecm\ISPM folder
#---------------------------------------------------------------------------------

ispm_ispm = ['ispm',
             {
             'ispma0.shp' : ('INDEX', 'VID', 'SCALE', 'AUTHOR', 'YEAR', 'ORG', 'FACTOR', 'ID_OBJ'),
             'ispma1.shp' : ('INDEX', 'VID', 'SCALE', 'AUTHOR', 'YEAR', 'ORG', 'FACTOR', 'ID_OBJ'),
             'ispma2.shp' : ('INDEX', 'VID', 'SCALE', 'AUTHOR', 'YEAR', 'ORG', 'FACTOR', 'ID_OBJ'),
             'ispma3.shp' : ('INDEX', 'VID', 'SCALE', 'AUTHOR', 'YEAR', 'ORG', 'FACTOR', 'ID_OBJ')
             }
             ]

leg_ispm = {'leg_ispm.dbf' : ('L_CODE', 'B_CODE', 'TEXT1', 'TEXT2', 'TEXT3')}

ispm = ['ispm', ispm_ispm, leg_ispm]

#---------------------------------------------------------------------------------



# ecm\SRL folder
#---------------------------------------------------------------------------------

hyps_srl = ['hyps',
            {
            'hypsa200.shp' : ('NAME', 'FACTOR'),
            'hypsa1000.shp' : ('NAME',),
            'hypsl.shp' : ()
            }
            ]

polt_srl = ['polt',
            {
            'polta.shp' : ('OKR', 'SUB', 'AVT'),
            'poltl.shp' : ()
            }
            ]

leg_srl = {'leg_srl.dbf' : ('L_CODE', 'B_CODE', 'TEXT1', 'TEXT2', 'TEXT3')}

srl = ['srl', hyps_srl, dnet, pplc, road, polt_srl, leg_srl]

#---------------------------------------------------------------------------------



#   ecm\NAFT folder
#---------------------------------------------------------------------------------

nres = ['nres',
        {
        'nresa.shp' : ('V_LEG',),
        'nresb.shp' : ()
        }
        ]
ndpro = ['ndpro',
         {
         'ndproa1.shp' : ('COMM',)
         }
         ]
nmfa2 = ['nmfa2',
        {
        'nmfa2a.shp' : ('COMM',),
        'nmfa2b.shp' : (),
        'nmfa2l.shp' : ('COMM',),
        'nmfa2p.shp' : ('COMM',)
        }
        ]
nmfa3 = ['nmfa3',
        {
        'nmfa3a.shp' : ('COMM',),
        'nmfa3b.shp' : ()
        }
        ]
prog = ['prog',
        {
        'proga1.shp' : ('NAME',),
        'proga2.shp' : ('NAME',),
        'proga3.shp' : ('NAME',),
        'progb.shp' : (),
        'progd.dbf' : ('IDD',)
        }
        ]
nsect = ['nsect',
        {
        'nsectl.shp' : ('N_LINE', 'TEXT'),
        'nsectp.shp' : ('N_LINE', 'N_POINT', 'T_POINT')    # l_code 
        }
        ]
naft_usl = ['naft_usl',
            {
            'naft_usla.shp' : ('KRAP', 'INDEX', 'NAME', 'FACTOR', 'noSpatRef'),
            'naft_usll.shp' : ('INDEX', 'NAME', 'FACTOR', 'noSpatRef'),
            'naft_uslp.shp' : ('INDEX', 'NAME', 'AZIMUT', 'FACTOR', 'noSpatRef'),
            'dopl.shp' : ()
            }
            ]
nafts = ['nafts']

leg_naft = {'leg_naft.dbf' : ('L_CODE', 'B_CODE', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')}

naft = ['naft', nres, ndpro, isln, fys, chem, nmfa2, nmfa3, prog, nsect, naft_usl, nafts, leg_naft]

#---------------------------------------------------------------------------------



#   ecm\GIDR folder
#---------------------------------------------------------------------------------

leg_gidr = {'leg_gidr.dbf' : ('L_CODE', 'B_CODE', 'INDEX', 'TEXT1', 'TEXT2', 'TEXT3', 'TEXT4')}

gidr = ['gidr', leg_gidr]

#---------------------------------------------------------------------------------

ecm_template = [topo, geol, quart, INT, bott, sfr, tect, grav, magn, naft, ecol, ispm, srl, gidr]
ecm = [sheetNameShort]

for i in range(14):
    if GetParameterAsText(i + 5) == 'true':
        ecm.append(ecm_template[i])
        
#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------




# MAK folder
#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------

maket = ['maket']
usl = ['usl']
arc = ['arc']
dop = ['dop']


mak = [sheetNameShort + '_mak', maket, usl, arc, dop]

#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------




# ZAP folder
#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------

text  = [u'']
tabl = [u'']
illustr = [u'']
pril = [u'']


zap = [sheetNameShort + '_zap', text, tabl, illustr, pril]

#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------




# DB folder
#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------

oobs_kfm = ['oobs',
            {
            'oobsl.shp' : ('N', 'AUTHOR', 'TYPE', 'ISTD', 'LINK', 'FACTOR', 'ID_OBJ'),
            'oobsp.shp' : ('NAME', 'AUTHOR', 'H', 'INDEXZ', 'MAP', 'ISTD', 'LINK', 'FACTOR', 'ID_OBJ')
            }
            ]
oopr_kfm = ['oopr', {'ooprp.shp' : ('NAME', 'INTERVAL', 'ISTD', 'LINK', 'FACTOR', 'ID_OBJ')}]
land_kfm = ['land', {'landa.shp' : ('KRAP',)}]
detr = ['detr', {'detra.shp' : ('N', 'NAME')}]
stra = ['stra', {'strap.shp' : ('LINK', 'N', 'INDEXS', 'TSTRAT', 'NAME', 'ID_OBJ')}]
petr = ['petr',
        {
        'petra.shp' : ('MARK', 'LINK', 'N', 'INDEXP', 'TPETR', 'NAME', 'ID_OBJ'),
        'petrl.shp' : ('MARK', 'LINK', 'N', 'INDEXP', 'TPETR', 'NAME', 'ID_OBJ'),
        'petrp.shp' : ('MARK', 'LINK', 'N', 'INDEXP', 'TPETR', 'NAME', 'ID_OBJ')
        }
        ]

if sheetNum200:
    kfm_comp = ['kfm_comp', oobs_kfm, oopr_kfm, land_kfm, detr]
else:
    kfm_comp = ['kfm_comp', oobs_kfm, oopr_kfm, land_kfm, detr, stra, petr]

leg_kfm = {'leg_kfm.dbf' : ('L_CODE', 'B_CODE', 'TEXT1', 'TEXT2', 'TEXT3')}
kfm = ['kfm', kfm_comp, leg_kfm]

krop_comp = ['krop_comp']
leg_krop = {'leg_krop.dbf' : ('L_CODE', 'TEXT1', 'TEXT2')}
krop = ['krop', krop_comp, leg_krop]

fakt_mak = ['fakt_mak', dop, usl]

db = ['db']
sbd = ['sbd']
bpd = ['bpd', db, sbd]

fakt = ['fakt', kfm, krop, fakt_mak, bpd]

analiz = ['analiz']

etalon = ['etalon']

polisk = ['polisk']

izuch_mak = ['izuch_mak']
ecm_izuch = [sheetNameShort + '_izu', {'leg_izuch.dbf' : ('L_CODE', 'B_CODE', 'INDEX', 'TEXT1', 'TEXT2')}]
izuch = ['izuch', izuch_mak, ecm_izuch]

dist = ['dist']

ogfo = ['ogfo']

ogho = ['ogho']

dopm = ['dopm']

zaram = ['zaram']


db = [sheetNameShort + '_db', fakt, analiz, etalon, polisk, izuch, dist, ogfo, ogho, dopm, zaram]

#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------




# DKM folder
#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------

dkm = [sheetNameShort + '_dkm']

#---------------------------------------------------------------------------------
#---------------------------------------------------------------------------------



headFolder = [sheetNameLong, ecm, mak, zap, db, dkm]



#---------------------------------------------------------------------------------





#--------------------------IMPLEMENTATION-------------------------------------



propertiesList = attrTablPropList

createFolder(root, headFolder, addFields, propertiesList)
