# -*- coding: cp1251 -*-


"""
Tool Name:     Create Legend Scale
Source Name:   CreateLegendScale.py
Version:       ArcGIS 10.x
Author:        Anatoly Baranov
Organization:  VSEGEI
Description:   Creates legend scale to the geophisical, geochemical,
    ecological and other maps, presented in halos or isolines
Requires an integer type field in shp with unique codings
"""




import arcpy
import os



#---------------------------------------- I N P U T S ----------------------------------------


inputFeatureClass = arcpy.GetParameterAsText(0) # shapefile to be used as legend base
inputFieldName = arcpy.GetParameterAsText(1) # field with unique codings / integer
outputFeatureClass = arcpy.GetParameterAsText(2) # existing shapefile (without georeferencing) witch will contain legend scale
outputFieldName = arcpy.GetParameterAsText(3) # field to add unique codings from primary shapefile / integer
scaleOrientation = arcpy.GetParameterAsText(4) # legend scale orientation and position of label points
rectWidth = arcpy.GetParameterAsText(5) # width of a legend box, cm
rectHeight = arcpy.GetParameterAsText(6) # height of a legend box, cm

rectWidth = float(rectWidth.replace(',', '.'))
rectHeight = float(rectHeight.replace(',', '.'))


#------------------------------------------------------------------------------------------------------



rows = arcpy.SearchCursor(inputFeatureClass, '', '', inputFieldName)


# getting a list of unique codings
uniqueValues = set([row.getValue(inputFieldName) for row in rows])
uniqueValues = list(uniqueValues)
uniqueValues.sort()

points = [] # Array to save x-coords of points for labels which are the same as x-coords of borders between scale boxes


# displaying unique codings in a message
for val in uniqueValues:
    arcpy.AddMessage(str(val))


arcpy.DeleteRows_management(outputFeatureClass) # deleting data from output shp-file

# creating a legend box for every unique coding
for val in range(len(uniqueValues)):

    if "HORIZONTAL" in scaleOrientation:
        x = val * rectWidth
        coordList = [ [ [x, 0], [x + rectWidth, 0], [x + rectWidth, rectHeight], [x, rectHeight] ] ]
        points.append(x)

    elif "VERTICAL" in scaleOrientation:
        y = val * rectHeight
        coordList = [ [ [0, y], [0, y + rectHeight], [rectWidth, y + rectHeight], [rectWidth, y] ] ]
        points.append(y)

    cursor = arcpy.InsertCursor(outputFeatureClass)

    point = arcpy.Point()
    array = arcpy.Array()
    for feature in coordList:
        for coordPair in feature:
            point.X = coordPair[0]
            point.Y = coordPair[1]
            array.add(point)
        array.add(array.getObject(0))
        polygon = arcpy.Polygon(array)

    # writing a coding value to the attribute table of legend box element
    row = cursor.newRow()
    row.setValue(outputFieldName, uniqueValues[val])
    row.shape = array
    cursor.insertRow(row)
    array.add(point)
    array.removeAll()

    del row
        



outFile = os.path.dirname(outputFeatureClass) + '\\label_points.shp'

if not "NO_LABELS" in scaleOrientation:
    if "HORIZONTAL" in scaleOrientation:
        points.append(points[-1] + rectWidth)
    elif "VERTICAL" in scaleOrientation:
        points.append(points[-1] + rectHeight)

    if "ABOVE" in scaleOrientation:
        pointsList = [ [x, rectHeight + .3] for x in points ]
    elif "BELOW" in scaleOrientation:
        pointsList = [ [x, -.3] for x in points ]
    elif "LEFT" in scaleOrientation:
        pointsList = [ [-.3, y] for y in points ]
    elif "RIGHT" in scaleOrientation:
        pointsList = [ [rectWidth + .3, y] for y in points ]

    l = len(pointsList)
    if l % 2 == 0:
        l = int(l / 2)
        xAdd = ( pointsList[l][0] + pointsList[l - 1][0] ) / 2
    else:
        l = int(l / 2)
        xAdd = pointsList[l][0]

    if "ABOVE" in scaleOrientation:
        pointsList.append( [xAdd, rectHeight + .8] )
    elif "BELOW" in scaleOrientation:
        pointsList.append( [xAdd, rectHeight + .5] )
    elif "LEFT" in scaleOrientation or "RIGHT" in scaleOrientation:
        pointsList.append( [rectWidth / 2, y + .5] )

    point = arcpy.Point()
    pointGeometryList = []

    for pnt in pointsList:
        point.X = pnt[0]
        point.Y = pnt[1]
        pointGeometry = arcpy.PointGeometry(point)
        pointGeometryList.append(pointGeometry)


    arcpy.CopyFeatures_management(pointGeometryList, outFile)
    arcpy.AddField_management(outFile, 'L_code', 'LONG')
    arcpy.AddField_management(outFile, 'Text', 'TEXT')
